# OpenCat GIF Assets

Place your state GIF files here:

- `sleeping.gif`
- `connecting.gif`
- `idle.gif`
- `thinking.gif`
- `talking.gif`
- `done.gif`
- `error.gif`

They are mapped via `manifest.json`.
